==> jasmit_firestarter-0.2.2.tar.gz: jasmit_firestarter-0.2.2/src/jasmit_firestarter/std_app.py <==
"""
std_app.py
This module defines the StdApp class, which is a base class for creating
standard applications. The StdApp class provides methods for setting
command line parameters and configuration file parameters. It also
provides a logger for logging messages to a file.   
"""

import configparser

from std_logging import StdLogging, function_logger


#  =============================================================================
class StdApp:
    #  -----------------------------------------------------------------------------
    def __init__(self, app_name="", version="0.0.0") -> None:
        self._logger = StdLogging(f"logs/{app_name}.log")
        self._logger.info(f"Begin 'StdApp.__init__         ' arguments - ({app_name=}, {version=})")

        self._app_name = app_name
        self.__version__ = version

        self.cmdline_params = self.set_cmdline_params()
        self.cfg_file_params = self.set_cfg_file_params()

        self._logger.info("End   'StdApp.__init__         ' returns   - None\n")

    # ---------------------------------------------------------------------------------------------------------------------
    def __str__(self):
        return "StdApp"

    __repr__ = __str__

    #  -----------------------------------------------------------------------------
    @function_logger
    def set_cmdline_params(self):
        raise NotImplementedError("Please define set_cmdline_params in the derived class.")

    #  -----------------------------------------------------------------------------
    @function_logger
    def set_cfg_file_params(self):
        environment = self.cmdline_params.get("environment")

        cfgfile_path = self.cmdline_params.get("cfgfile")
        config = configparser.ConfigParser()
        with open(cfgfile_path) as file:
            config.read_file(file)

        return config[environment]

==> jasmit_firestarter-0.2.4.tar.gz: jasmit_firestarter-0.2.4/src/jasmit_firestarter/std_app.py <==
"""
std_app.py
This module defines the StdApp class, which is a base class for creating
standard applications. The StdApp class provides methods for setting
command line parameters and configuration file parameters. It also
provides a logger for logging messages to a file.   
"""

import configparser

from .std_logging import StdLogging, function_logger


#  =============================================================================
class StdApp:
    #  -----------------------------------------------------------------------------
    def __init__(self, app_name="", version="0.0.0") -> None:
        self._logger = StdLogging(f"logs/{app_name}.log")
        self._logger.info(f"Begin 'StdApp.__init__         ' arguments - ({app_name=}, {version=})")

        self._app_name = app_name
        self.__version__ = version

        self.cmdline_params = self.set_cmdline_params()
        self.cfg_file_params = self.set_cfg_file_params()

        self._logger.info("End   'StdApp.__init__         ' returns   - None\n")

    # ---------------------------------------------------------------------------------------------------------------------
    def __str__(self):
        return "StdApp"

    __repr__ = __str__

    #  -----------------------------------------------------------------------------
    @function_logger
    def set_cmdline_params(self):
        raise NotImplementedError("Please define set_cmdline_params in the derived class.")

    #  -----------------------------------------------------------------------------
    @function_logger
    def set_cfg_file_params(self):
        environment = self.cmdline_params.get("environment")

        cfgfile_path = self.cmdline_params.get("cfgfile")
        config = configparser.ConfigParser()
        with open(cfgfile_path) as file:
            config.read_file(file)

        return config[environment]
